@@ -1,18 +1,8 @@
-from rc.exception import UploadException, DownloadException, SSHException
+from rc.exception import UploadException, DownloadException
 from io import StringIO
 from rc.util import run, run_stream, convert_list_command_to_str
 
 
-def tmuxize(cmd):
-    result = StringIO()
-    for c in cmd:
-        if c == "'":
-            result.write("\"'\" ")
-        else:
-            result.write(f"'{c}' ")
-    return result.getvalue()
-
-
 class Machine:
     def __init__(self, *, provider, name, zone, ip, username, ssh_key_path):
         self.provider = provider
@@ -66,7 +56,7 @@ class Machine:
 
     def _ssh_shell(self):
         return ['ssh', '-o', 'StrictHostKeyChecking=no',
-                '-i', self.ssh_key_path, self.username + '@' + self.ip, '--']
+                *(['-i', self.ssh_key_path] if self.ssh_key_path else []), self.username + '@' + self.ip, '--']
 
     def run(self, cmd, *, timeout=None, input=None):
         return run(cmd, shell=self._ssh_shell(), timeout=timeout, input=input)
@@ -80,3 +70,5 @@ class Machine:
     def kill_detach_tmux(self, name='python-rc'):
         return self.run(f"tmux kill-session -t {name}")
 
+    def save_image(self, image, **kwargs):
+        return self.provider.save_image(self, image, **kwargs)
